# -*- coding:utf-8 -*-
"""
资产仓库 cmd client
支持本地资产上传
支持下载服务端资产
"""
import argparse
import ast
import os.path
from yeying.api.asset import asset_pb2, namespace_pb2
from yeying.api.web3 import Identity, SecurityAlgorithm
from yeying.client.downloader import DownloadResult
from yeying.client.model.file import File
from yeying.client.model.option import ProviderOption
from yeying.client.provider.asset_provider import AssetProvider
from yeying.client.provider.namespace_provider import NamespaceProvider
from yeying.client.tool.identity_service import load, decrypt_block_address
from yeying.client.uploader import UploadResult
from yeying.client import uploader, downloader
from google.protobuf.json_format import MessageToJson


def arg_parse():
    parser = argparse.ArgumentParser(description="Yeying warehouse cli")
    sub_parser= parser.add_subparsers(dest="command")

    # 上传本地资源
    put_parser = sub_parser.add_parser("put", help="上传资源")
    # proxy 参数可选，默认连接本地服务
    put_parser.add_argument(dest="proxy", help="envoy proxy address (optional), default value http://localhost:8641", nargs="?", default="http://localhost:8641")
    put_parser.add_argument(dest="source", help="local file path")
    put_parser.add_argument(dest="namespace_id", help="namespace_id")
    # encrypted 是否需要加密
    put_parser.add_argument(dest="encrypted", help="is encrypted")
    put_parser.add_argument(dest="identity_file", help="identity file")
    put_parser.add_argument(dest="password", help="password")


    # 下载服务端资源
    get_parser = sub_parser.add_parser("get", help="下载资源")
    # proxy 参数可选，默认连接本地服务
    get_parser.add_argument(dest="proxy", help="envoy proxy address (optional), default value http://localhost:8641", nargs="?", default="http://localhost:8641")
    get_parser.add_argument(dest="namespace_id", help="namespace_id")
    get_parser.add_argument(dest="hash", help="hash")
    get_parser.add_argument(dest="output", help="local file out path")
    get_parser.add_argument(dest="identity_file", help="identity file")
    get_parser.add_argument(dest="password", help="password")


    # 删除服务端资源
    delete_parser = sub_parser.add_parser("delete", help="删除资源")
    # proxy 参数可选，默认连接本地服务
    delete_parser.add_argument(dest="proxy", help="envoy proxy address (optional), default value http://localhost:8641", nargs="?", default="http://localhost:8641")
    delete_parser.add_argument(dest="namespace_id", help="namespace_id")
    delete_parser.add_argument(dest="hash", help="hash")
    delete_parser.add_argument(dest="identity_file", help="identity file")
    delete_parser.add_argument(dest="password", help="password")

    # 创建 namespace
    create_namespace_parser = sub_parser.add_parser("createNamespace", help="创建 namespace")
    # proxy 参数可选，默认连接本地服务
    create_namespace_parser.add_argument(dest="proxy", help="envoy proxy address (optional), default value http://localhost:8641", nargs="?", default="http://localhost:8641")
    create_namespace_parser.add_argument(dest="name", help="namespace name")
    create_namespace_parser.add_argument(dest="description", help="description")
    create_namespace_parser.add_argument(dest="identity_file", help="identity file")
    create_namespace_parser.add_argument(dest="password", help="password")


    args = parser.parse_args()
    return args, parser


def package_dir(path):
    import uuid
    dst = "/tmp/%s.tar.gz" % str(uuid.uuid1().hex)[:8]
    cmd = "mkdir -p /tmp; tar -czf {dst} {src}".format(src=path, dst=dst)
    os.system(cmd)
    return dst


def upload(args, option, algorithm: SecurityAlgorithm):
    print("start upload")
    print(args)

    def upload_callback(result: UploadResult) -> None:
        print(f"[文件上传回调] 进度: {result['progress']['completed']}/{result['progress']['total']}")
        print(f"[文件上传回调] 区块namespaceId: {result['block'].namespaceId}")
        print(f"[文件上传回调] 区块大小: {result['block'].size} 字节")
        print(f"[文件上传回调] 区块哈希: {result['block'].hash}")
        print("-" * 40)

    if not os.path.exists(args.source):
        print("Invalid path %s" % args.source)
    else:
        path = args.source
        if os.path.isdir(path):
            print("packaging folder %s" % path)
            path = package_dir(path)
            print("packaging folder temp file %s" % path)
        upload_client = uploader.Uploader(option, algorithm)
        file = File(name=os.path.basename(path), size=os.stat(path).st_size, stream=path, last_modified=int(os.stat(path).st_mtime * 1000))
        res: asset_pb2.SignAssetResponse = upload_client.put(namespace_id=args.namespace_id, file=file, encrypted=ast.literal_eval(args.encrypted), block_callback=upload_callback)
        asset = res.body.asset
        print(f"upload success. asset={MessageToJson(asset)}")


def download(args, option, algorithm: SecurityAlgorithm):
    print("start download")
    print(args)
    download_client = downloader.Downloader(option, algorithm)
    namespace_id = args.namespace_id
    chunk_files = []
    def download_callback(result: DownloadResult) -> None:
        print(f"[文件下载回调] 进度: {result['progress']['completed']}/{result['progress']['total']}")
        print(f"[文件下载回调] 区块namespaceId: {result['block'].namespaceId}")
        print(f"[文件下载回调] 区块大小: {len(result['data'])} 字节")
        print(f"[文件下载回调] 区块哈希: {result['block'].hash}")
        chunk_files.append(result['data'])
        print("-" * 40)
    asset = download_client.get(namespace_id=namespace_id, _hash=args.hash, block_callback=download_callback)

    def merge_files(chunks, output_path):
        """合并分块文件为完整文件"""
        with open(output_path, 'wb') as output:
            for chunk in chunks:
                output.write(chunk)
        print(f"文件已合并至: {output_path}")

    merge_files(chunk_files, args.output)
    print(f"download success. asset={MessageToJson(asset)}")


def get_proxy(args):
    return args.proxy if args.proxy else os.getenv("WAREHOUSE_ENDPOINT", "http://localhost:8641")


def delete(args, option):
    print("start delete")
    print(f"namespace_id={args.namespace_id}")
    print(f"hash={args.hash}")
    print(f"proxy={option.proxy}")
    delete_client = AssetProvider(option=option)
    response: asset_pb2.DeleteAssetResponse = delete_client.delete(args.namespace_id, args.hash)
    print(f"delete success. code={response.body.status.code}")


def create_namespace(args, option):
    print("start create namespace")
    print(f"namespace name={args.name}")
    print(f"description={args.description}")
    print(f"proxy={option.proxy}")
    namespace_client = NamespaceProvider(option=option)
    res: namespace_pb2.CreateNamespaceResponse = namespace_client.create(args.name, args.description)
    print(f"create namespace success. namespace={MessageToJson(res.body.namespace)}")


def main():
    args, parser = arg_parse()
    identity_file = args.identity_file
    if not os.path.exists(identity_file):
        raise Exception(f"identity_file not exists {identity_file}")

    identity: Identity = load(identity_file)
    block_address = decrypt_block_address(identity.blockAddress, identity.securityConfig.algorithm, args.password)
    print(f"block_address={block_address}")
    option = ProviderOption(
        proxy=get_proxy(args),
        block_address=block_address
    )
    if args.command == "put":
        upload(args, option, identity.securityConfig.algorithm)
    elif args.command == "get":
        download(args, option, identity.securityConfig.algorithm)
    elif args.command == "delete":
        delete(args, option)
    elif args.command == "createNamespace":
        create_namespace(args, option)
    else:
        parser.print_help()


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/config/config.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/config/config.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/config/config.proto\x12\x11yeying.api.config\x1a\x1fyeying/api/common/message.proto"{\n\x10GetConfigRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.config.GetConfigRequestBody"T\n\x14GetConfigRequestBody\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.yeying.api.config.ConfigTypeEnum"}\n\x11GetConfigResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.config.GetConfigResponseBody"}\n\x15GetConfigResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.yeying.api.config.ConfigMetadata"{\n\x10SetConfigRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.config.SetConfigRequestBody"I\n\x14SetConfigRequestBody\x12\x31\n\x06\x63onfig\x18\x01 \x01(\x0b\x32!.yeying.api.config.ConfigMetadata"}\n\x11SetConfigResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.config.SetConfigResponseBody"}\n\x15SetConfigResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.yeying.api.config.ConfigMetadata"t\n\x0e\x43onfigMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\t\x12\x11\n\tupdatedAt\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\t*W\n\x0e\x43onfigTypeEnum\x12\x17\n\x13\x43ONFIG_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12\x43ONFIG_TYPE_SYSTEM\x10\x01\x12\x14\n\x10\x43ONFIG_TYPE_USER\x10\x02\x32\xb0\x01\n\x06\x43onfig\x12R\n\x03Set\x12#.yeying.api.config.SetConfigRequest\x1a$.yeying.api.config.SetConfigResponse"\x00\x12R\n\x03Get\x12#.yeying.api.config.GetConfigRequest\x1a$.yeying.api.config.GetConfigResponse"\x00\x42\x13Z\x11yeying/api/configb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.config.config_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/config"
    _globals["_CONFIGTYPEENUM"]._serialized_start = 1123
    _globals["_CONFIGTYPEENUM"]._serialized_end = 1210
    _globals["_GETCONFIGREQUEST"]._serialized_start = 86
    _globals["_GETCONFIGREQUEST"]._serialized_end = 209
    _globals["_GETCONFIGREQUESTBODY"]._serialized_start = 211
    _globals["_GETCONFIGREQUESTBODY"]._serialized_end = 295
    _globals["_GETCONFIGRESPONSE"]._serialized_start = 297
    _globals["_GETCONFIGRESPONSE"]._serialized_end = 422
    _globals["_GETCONFIGRESPONSEBODY"]._serialized_start = 424
    _globals["_GETCONFIGRESPONSEBODY"]._serialized_end = 549
    _globals["_SETCONFIGREQUEST"]._serialized_start = 551
    _globals["_SETCONFIGREQUEST"]._serialized_end = 674
    _globals["_SETCONFIGREQUESTBODY"]._serialized_start = 676
    _globals["_SETCONFIGREQUESTBODY"]._serialized_end = 749
    _globals["_SETCONFIGRESPONSE"]._serialized_start = 751
    _globals["_SETCONFIGRESPONSE"]._serialized_end = 876
    _globals["_SETCONFIGRESPONSEBODY"]._serialized_start = 878
    _globals["_SETCONFIGRESPONSEBODY"]._serialized_end = 1003
    _globals["_CONFIGMETADATA"]._serialized_start = 1005
    _globals["_CONFIGMETADATA"]._serialized_end = 1121
    _globals["_CONFIG"]._serialized_start = 1213
    _globals["_CONFIG"]._serialized_end = 1389
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .imagecontent_pb2 import ImageContentTypeEnum
from .imagecontent_pb2 import TaskStatusEnum
from .meta_pb2 import GroupMetaData
from .meta_pb2 import ArchiveMetadata
from .meta_pb2 import HomeworkMetadata
from .meta_pb2 import MistakesMetadata
from .meta_pb2 import MessageMetadata
from .meta_pb2 import TaskMetadata
from .meta_pb2 import TagCountMeta
from .meta_pb2 import TaskTagMetadata
from .meta_pb2 import WarehouseMetadata
from .meta_pb2 import UrlMetaData
from .archive_pb2 import ArchiveListRequest
from .archive_pb2 import ArchiveListRequestBody
from .archive_pb2 import ArchiveListResponse
from .archive_pb2 import ArchiveListResponseBody
from .archive_pb2 import ArchiveDetailRequest
from .archive_pb2 import ArchiveDetailRequestBody
from .archive_pb2 import ArchiveDetailResponse
from .archive_pb2 import ArchiveDetailResponseBody
from .archive_pb2 import ArchiveDetailStudentRequest
from .archive_pb2 import ArchiveDetailStudentRequestBody
from .archive_pb2 import ArchiveDetailStudentResponse
from .archive_pb2 import ArchiveDetailStudentResponseBody
from .archive_pb2 import ArchiveAddRequest
from .archive_pb2 import ArchiveAddRequestBody
from .archive_pb2 import ArchiveAddResponse
from .archive_pb2 import ArchiveAddResponseBody
from .archive_pb2 import ArchiveDeleteRequest
from .archive_pb2 import ArchiveDeleteRequestBody
from .archive_pb2 import ArchiveDeleteResponse
from .archive_pb2 import ArchiveDeleteResponseBody
from .archive_pb2 import ArchiveUpdateRequest
from .archive_pb2 import ArchiveUpdateRequestBody
from .archive_pb2 import ArchiveUpdateResponse
from .archive_pb2 import ArchiveUpdateResponseBody
from .archive_pb2_grpc import ArchiveServicer
from .archive_pb2_grpc import ArchiveStub
from .archive_pb2_grpc import add_ArchiveServicer_to_server
from .archive_pb2_grpc import Archive
from .assignment_pb2 import AssignmentUploadRequest
from .assignment_pb2 import AssignmentUploadRequestBody
from .assignment_pb2 import AssignmentUploadResponse
from .assignment_pb2 import AssignmentUploadResponseBody
from .assignment_pb2 import AssignmentBigModelRequest
from .assignment_pb2 import AssignmentBigModelRequestBody
from .assignment_pb2 import AssignmentBigModelResponse
from .assignment_pb2 import AssignmentBigModelResponseBody
from .assignment_pb2 import AssignmentArtificialRequest
from .assignment_pb2 import AssignmentArtificialRequestBody
from .assignment_pb2 import AssignmentArtificialResponse
from .assignment_pb2 import AssignmentArtificialResponseBody
from .assignment_pb2 import StudentActionRequest
from .assignment_pb2 import StudentActionRequestBody
from .assignment_pb2 import StudentActionResponse
from .assignment_pb2 import StudentActionResponseBody
from .assignment_pb2 import AssignmentCorrectionRequest
from .assignment_pb2 import AssignmentCorrectionRequestBody
from .assignment_pb2 import AssignmentCorrectionResponse
from .assignment_pb2 import AssignmentCorrectionResponseBody
from .assignment_pb2_grpc import AssignmentServicer
from .assignment_pb2_grpc import AssignmentStub
from .assignment_pb2_grpc import add_AssignmentServicer_to_server
from .assignment_pb2_grpc import Assignment
from .group_pb2 import AddGroupRequest
from .group_pb2 import AddGroupRequestBody
from .group_pb2 import AddGroupResponse
from .group_pb2 import AddGroupResponseBody
from .group_pb2 import DetailGroupRequest
from .group_pb2 import DetailGroupRequestBody
from .group_pb2 import DetailGroupResponse
from .group_pb2 import DetailGroupResponseBody
from .group_pb2 import ListGroupRequest
from .group_pb2 import ListGroupRequestBody
from .group_pb2 import ListGroupResponse
from .group_pb2 import ListGroupResponseBody
from .group_pb2 import UpdateGroupRequest
from .group_pb2 import UpdateGroupRequestBody
from .group_pb2 import UpdateGroupResponse
from .group_pb2 import UpdateGroupResponseBody
from .group_pb2 import DeleteGroupRequest
from .group_pb2 import DeleteGroupRequestBody
from .group_pb2 import DeleteGroupResponse
from .group_pb2 import DeleteGroupResponseBody
from .group_pb2_grpc import GroupServicer
from .group_pb2_grpc import GroupStub
from .group_pb2_grpc import add_GroupServicer_to_server
from .group_pb2_grpc import Group
from .homework_pb2 import HomeworkListRequest
from .homework_pb2 import HomeworkListRequestBody
from .homework_pb2 import HomeworkListResponse
from .homework_pb2 import HomeworkListResponseBody
from .homework_pb2 import HomeworkDetailRequest
from .homework_pb2 import HomeworkDetailRequestBody
from .homework_pb2 import HomeworkDetailResponse
from .homework_pb2 import HomeworkDetailResponseBody
from .homework_pb2_grpc import HomeworkServicer
from .homework_pb2_grpc import HomeworkStub
from .homework_pb2_grpc import add_HomeworkServicer_to_server
from .homework_pb2_grpc import Homework
from .message_pb2 import MessageListRequest
from .message_pb2 import MessageListRequestBody
from .message_pb2 import MessageListResponse
from .message_pb2 import MessageListResponseBody
from .message_pb2 import CountRequest
from .message_pb2 import CountRequestBody
from .message_pb2 import CountResponse
from .message_pb2 import CountResponseBody
from .message_pb2 import CountMetadata
from .message_pb2 import ListByRequest
from .message_pb2 import ListByRequestBody
from .message_pb2 import ListByResponse
from .message_pb2 import ListByResponseBody
from .message_pb2 import MarkAsReadRequest
from .message_pb2 import MarkAsReadRequestBody
from .message_pb2 import MarkAsReadResponse
from .message_pb2 import MarkAsReadResponseBody
from .message_pb2_grpc import MessageServicer
from .message_pb2_grpc import MessageStub
from .message_pb2_grpc import add_MessageServicer_to_server
from .message_pb2_grpc import Message
from .mistakes_pb2 import MistakesListRequest
from .mistakes_pb2 import MistakesListRequestBody
from .mistakes_pb2 import MistakesListResponse
from .mistakes_pb2 import MistakesListResponseBody
from .mistakes_pb2 import MistakesDetailRequest
from .mistakes_pb2 import MistakesDetailRequestBody
from .mistakes_pb2 import MistakesDetailResponse
from .mistakes_pb2 import MistakesDetailResponseBody
from .mistakes_pb2 import MistakesAnalysisRequest
from .mistakes_pb2 import MistakesAnalysisRequestBody
from .mistakes_pb2 import MistakesAnalysisResponse
from .mistakes_pb2 import MistakesAnalysisResponseBody
from .mistakes_pb2 import MakeCorrectionRequest
from .mistakes_pb2 import MakeCorrectionRequestBody
from .mistakes_pb2 import MakeCorrectionResponse
from .mistakes_pb2 import MakeCorrectionResponseBody
from .mistakes_pb2 import MistakesPrintRequest
from .mistakes_pb2 import MistakesPrintRequestBody
from .mistakes_pb2 import MistakesPrintResponse
from .mistakes_pb2 import MistakesPrintResponseBody
from .mistakes_pb2 import MistakesSubmitRequest
from .mistakes_pb2 import MistakesSubmitRequestBody
from .mistakes_pb2 import MistakesSubmitResponse
from .mistakes_pb2 import MistakesSubmitResponseBody
from .mistakes_pb2_grpc import MistakesServicer
from .mistakes_pb2_grpc import MistakesStub
from .mistakes_pb2_grpc import add_MistakesServicer_to_server
from .mistakes_pb2_grpc import Mistakes
from .task_pb2 import AddTaskRequest
from .task_pb2 import AddTaskRequestBody
from .task_pb2 import AddTaskResponse
from .task_pb2 import AddTaskResponseBody
from .task_pb2 import DetailTaskRequest
from .task_pb2 import DetailTaskRequestBody
from .task_pb2 import DetailTaskResponse
from .task_pb2 import DetailTaskResponseBody
from .task_pb2 import ListTaskRequest
from .task_pb2 import ListTaskRequestBody
from .task_pb2 import ListTaskResponse
from .task_pb2 import ListTaskResponseBody
from .task_pb2 import TagCountTaskRequest
from .task_pb2 import TagCountTaskRequestBody
from .task_pb2 import TagCountTaskResponse
from .task_pb2 import TagCountTaskResponseBody
from .task_pb2 import UpdateTaskRequest
from .task_pb2 import UpdateTaskRequestBody
from .task_pb2 import UpdateTaskResponse
from .task_pb2 import UpdateTaskResponseBody
from .task_pb2 import DeleteTaskRequest
from .task_pb2 import DeleteTaskRequestBody
from .task_pb2 import DeleteTaskResponse
from .task_pb2 import DeleteTaskResponseBody
from .task_pb2_grpc import TaskServicer
from .task_pb2_grpc import TaskStub
from .task_pb2_grpc import add_TaskServicer_to_server
from .task_pb2_grpc import Task
from .tasktag_pb2 import AddTaskTagRequest
from .tasktag_pb2 import AddTaskTagRequestBody
from .tasktag_pb2 import AddTaskTagResponse
from .tasktag_pb2 import AddTaskTagResponseBody
from .tasktag_pb2 import DetailTaskTagRequest
from .tasktag_pb2 import DetailTaskTagRequestBody
from .tasktag_pb2 import DetailTaskTagResponse
from .tasktag_pb2 import DetailTaskTagResponseBody
from .tasktag_pb2 import ListTaskTagRequest
from .tasktag_pb2 import ListTaskTagRequestBody
from .tasktag_pb2 import ListTaskTagResponse
from .tasktag_pb2 import ListTaskTagResponseBody
from .tasktag_pb2 import UpdateTaskTagRequest
from .tasktag_pb2 import UpdateTaskTagRequestBody
from .tasktag_pb2 import UpdateTaskTagResponse
from .tasktag_pb2 import UpdateTaskTagResponseBody
from .tasktag_pb2 import DeleteTaskTagRequest
from .tasktag_pb2 import DeleteTaskTagRequestBody
from .tasktag_pb2 import DeleteTaskTagResponse
from .tasktag_pb2 import DeleteTaskTagResponseBody
from .tasktag_pb2_grpc import TaskTagServicer
from .tasktag_pb2_grpc import TaskTagStub
from .tasktag_pb2_grpc import add_TaskTagServicer_to_server
from .tasktag_pb2_grpc import TaskTag
from .warehouse_pb2 import DetailWarehouseRequest
from .warehouse_pb2 import DetailWarehouseRequestBody
from .warehouse_pb2 import DetailWarehouseResponse
from .warehouse_pb2 import DetailWarehouseResponseBody
from .warehouse_pb2 import AddWarehouseRequest
from .warehouse_pb2 import AddWarehouseRequestBody
from .warehouse_pb2 import AddWarehouseResponse
from .warehouse_pb2 import AddWarehouseResponseBody
from .warehouse_pb2 import ListWarehouseRequest
from .warehouse_pb2 import ListWarehouseRequestBody
from .warehouse_pb2 import ListWarehouseResponse
from .warehouse_pb2 import ListWarehouseResponseBody
from .warehouse_pb2_grpc import WarehouseServicer
from .warehouse_pb2_grpc import WarehouseStub
from .warehouse_pb2_grpc import add_WarehouseServicer_to_server
from .warehouse_pb2_grpc import Warehouse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/rag/memory.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'yeying/api/rag/memory.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1byeying/api/rag/memory.proto\x12\x0eyeying.api.rag\x1a\x1fyeying/api/common/message.proto\"~\n\x13\x43reateMemoryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.rag.CreateMemoryRequestBody\")\n\x17\x43reateMemoryRequestBody\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\"\x80\x01\n\x14\x43reateMemoryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.rag.CreateMemoryResponseBody\"`\n\x18\x43reateMemoryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x11\n\tmemory_id\x18\x02 \x01(\t\"x\n\x10\x41\x64\x64MemoryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.rag.AddMemoryRequestBody\"6\n\x14\x41\x64\x64MemoryRequestBody\x12\x11\n\tmemory_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"z\n\x11\x41\x64\x64MemoryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.rag.AddMemoryResponseBody\"J\n\x15\x41\x64\x64MemoryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\"~\n\x13\x44\x65leteMemoryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.rag.DeleteMemoryRequestBody\"9\n\x17\x44\x65leteMemoryRequestBody\x12\x11\n\tmemory_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x80\x01\n\x14\x44\x65leteMemoryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.rag.DeleteMemoryResponseBody\"M\n\x18\x44\x65leteMemoryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\x84\x02\n\x06Memory\x12U\n\x06\x43reate\x12#.yeying.api.rag.CreateMemoryRequest\x1a$.yeying.api.rag.CreateMemoryResponse\"\x00\x12L\n\x03\x41\x64\x64\x12 .yeying.api.rag.AddMemoryRequest\x1a!.yeying.api.rag.AddMemoryResponse\"\x00\x12U\n\x06\x44\x65lete\x12#.yeying.api.rag.DeleteMemoryRequest\x1a$.yeying.api.rag.DeleteMemoryResponse\"\x00\x42\x11Z\x0fyeying/api/rag/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yeying.api.rag.memory_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\017yeying/api/rag/'
  _globals['_CREATEMEMORYREQUEST']._serialized_start=80
  _globals['_CREATEMEMORYREQUEST']._serialized_end=206
  _globals['_CREATEMEMORYREQUESTBODY']._serialized_start=208
  _globals['_CREATEMEMORYREQUESTBODY']._serialized_end=249
  _globals['_CREATEMEMORYRESPONSE']._serialized_start=252
  _globals['_CREATEMEMORYRESPONSE']._serialized_end=380
  _globals['_CREATEMEMORYRESPONSEBODY']._serialized_start=382
  _globals['_CREATEMEMORYRESPONSEBODY']._serialized_end=478
  _globals['_ADDMEMORYREQUEST']._serialized_start=480
  _globals['_ADDMEMORYREQUEST']._serialized_end=600
  _globals['_ADDMEMORYREQUESTBODY']._serialized_start=602
  _globals['_ADDMEMORYREQUESTBODY']._serialized_end=656
  _globals['_ADDMEMORYRESPONSE']._serialized_start=658
  _globals['_ADDMEMORYRESPONSE']._serialized_end=780
  _globals['_ADDMEMORYRESPONSEBODY']._serialized_start=782
  _globals['_ADDMEMORYRESPONSEBODY']._serialized_end=856
  _globals['_DELETEMEMORYREQUEST']._serialized_start=858
  _globals['_DELETEMEMORYREQUEST']._serialized_end=984
  _globals['_DELETEMEMORYREQUESTBODY']._serialized_start=986
  _globals['_DELETEMEMORYREQUESTBODY']._serialized_end=1043
  _globals['_DELETEMEMORYRESPONSE']._serialized_start=1046
  _globals['_DELETEMEMORYRESPONSE']._serialized_end=1174
  _globals['_DELETEMEMORYRESPONSEBODY']._serialized_start=1176
  _globals['_DELETEMEMORYRESPONSEBODY']._serialized_end=1253
  _globals['_MEMORY']._serialized_start=1256
  _globals['_MEMORY']._serialized_end=1516
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class SearchAssetRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchAssetRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchAssetRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SearchAssetRequestBody(_message.Message):
    __slots__ = ("condition", "page")
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    condition: SearchAssetCondition
    page: _message_pb2.RequestPage
    def __init__(
        self,
        condition: _Optional[_Union[SearchAssetCondition, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class SearchAssetCondition(_message.Message):
    __slots__ = ("format", "hash", "namespaceId", "name")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    format: _code_pb2.DigitalFormatEnum
    hash: str
    namespaceId: str
    name: str
    def __init__(
        self,
        format: _Optional[_Union[_code_pb2.DigitalFormatEnum, str]] = ...,
        hash: _Optional[str] = ...,
        namespaceId: _Optional[str] = ...,
        name: _Optional[str] = ...,
    ) -> None: ...

class SearchAssetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchAssetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchAssetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SearchAssetResponseBody(_message.Message):
    __slots__ = ("status", "assets")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ASSETS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    assets: _containers.RepeatedCompositeFieldContainer[AssetMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        assets: _Optional[_Iterable[_Union[AssetMetadata, _Mapping]]] = ...,
    ) -> None: ...

class SignAssetRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SignAssetRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SignAssetRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SignAssetRequestBody(_message.Message):
    __slots__ = ("asset",)
    ASSET_FIELD_NUMBER: _ClassVar[int]
    asset: AssetMetadata
    def __init__(self, asset: _Optional[_Union[AssetMetadata, _Mapping]] = ...) -> None: ...

class SignAssetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SignAssetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SignAssetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SignAssetResponseBody(_message.Message):
    __slots__ = ("status", "asset")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ASSET_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    asset: AssetMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        asset: _Optional[_Union[AssetMetadata, _Mapping]] = ...,
    ) -> None: ...

class UpdateAssetRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateAssetRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateAssetRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateAssetRequestBody(_message.Message):
    __slots__ = ("asset",)
    ASSET_FIELD_NUMBER: _ClassVar[int]
    asset: AssetMetadata
    def __init__(self, asset: _Optional[_Union[AssetMetadata, _Mapping]] = ...) -> None: ...

class UpdateAssetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateAssetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateAssetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateAssetResponseBody(_message.Message):
    __slots__ = ("status", "asset")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ASSET_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    asset: AssetMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        asset: _Optional[_Union[AssetMetadata, _Mapping]] = ...,
    ) -> None: ...

class AssetDetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssetDetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssetDetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AssetDetailRequestBody(_message.Message):
    __slots__ = ("hash", "namespaceId")
    HASH_FIELD_NUMBER: _ClassVar[int]
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    hash: str
    namespaceId: str
    def __init__(self, hash: _Optional[str] = ..., namespaceId: _Optional[str] = ...) -> None: ...

class AssetDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssetDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssetDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AssetDetailResponseBody(_message.Message):
    __slots__ = ("status", "asset")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ASSET_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    asset: AssetMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        asset: _Optional[_Union[AssetMetadata, _Mapping]] = ...,
    ) -> None: ...

class DeleteAssetRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteAssetRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteAssetRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteAssetRequestBody(_message.Message):
    __slots__ = ("hash", "namespaceId")
    HASH_FIELD_NUMBER: _ClassVar[int]
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    hash: str
    namespaceId: str
    def __init__(self, hash: _Optional[str] = ..., namespaceId: _Optional[str] = ...) -> None: ...

class DeleteAssetResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteAssetResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteAssetResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteAssetResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class AssetMetadata(_message.Message):
    __slots__ = (
        "namespaceId",
        "owner",
        "parentHash",
        "hash",
        "version",
        "name",
        "chunks",
        "description",
        "format",
        "size",
        "createdAt",
        "updatedAt",
        "chunkCount",
        "chunkSize",
        "isEncrypted",
        "signature",
    )
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    PARENTHASH_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    CHUNKCOUNT_FIELD_NUMBER: _ClassVar[int]
    CHUNKSIZE_FIELD_NUMBER: _ClassVar[int]
    ISENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    namespaceId: str
    owner: str
    parentHash: str
    hash: str
    version: int
    name: str
    chunks: _containers.RepeatedScalarFieldContainer[str]
    description: str
    format: _code_pb2.DigitalFormatEnum
    size: int
    createdAt: str
    updatedAt: str
    chunkCount: int
    chunkSize: int
    isEncrypted: bool
    signature: str
    def __init__(
        self,
        namespaceId: _Optional[str] = ...,
        owner: _Optional[str] = ...,
        parentHash: _Optional[str] = ...,
        hash: _Optional[str] = ...,
        version: _Optional[int] = ...,
        name: _Optional[str] = ...,
        chunks: _Optional[_Iterable[str]] = ...,
        description: _Optional[str] = ...,
        format: _Optional[_Union[_code_pb2.DigitalFormatEnum, str]] = ...,
        size: _Optional[int] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        chunkCount: _Optional[int] = ...,
        chunkSize: _Optional[int] = ...,
        isEncrypted: bool = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as _meta_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class MistakesListRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesListRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesListRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesListRequestBody(_message.Message):
    __slots__ = ("did",)
    DID_FIELD_NUMBER: _ClassVar[int]
    did: str
    def __init__(self, did: _Optional[str] = ...) -> None: ...

class MistakesListResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesListResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesListResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesListResponseBody(_message.Message):
    __slots__ = ("status", "list")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    list: _containers.RepeatedCompositeFieldContainer[_meta_pb2.MistakesMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[_meta_pb2.MistakesMetadata, _Mapping]]] = ...,
    ) -> None: ...

class MistakesDetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesDetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesDetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesDetailRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class MistakesDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesDetailResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.MistakesMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.MistakesMetadata, _Mapping]] = ...,
    ) -> None: ...

class MistakesAnalysisRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesAnalysisRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesAnalysisRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesAnalysisRequestBody(_message.Message):
    __slots__ = ("qa",)
    QA_FIELD_NUMBER: _ClassVar[int]
    qa: str
    def __init__(self, qa: _Optional[str] = ...) -> None: ...

class MistakesAnalysisResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesAnalysisResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesAnalysisResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesAnalysisResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class MakeCorrectionRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MakeCorrectionRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MakeCorrectionRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MakeCorrectionRequestBody(_message.Message):
    __slots__ = ("qa",)
    QA_FIELD_NUMBER: _ClassVar[int]
    qa: str
    def __init__(self, qa: _Optional[str] = ...) -> None: ...

class MakeCorrectionResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MakeCorrectionResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MakeCorrectionResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MakeCorrectionResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class MistakesPrintRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesPrintRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesPrintRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesPrintRequestBody(_message.Message):
    __slots__ = ("qa",)
    QA_FIELD_NUMBER: _ClassVar[int]
    qa: str
    def __init__(self, qa: _Optional[str] = ...) -> None: ...

class MistakesPrintResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesPrintResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesPrintResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesPrintResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class MistakesSubmitRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesSubmitRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesSubmitRequestBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesSubmitRequestBody(_message.Message):
    __slots__ = ("qa",)
    QA_FIELD_NUMBER: _ClassVar[int]
    qa: str
    def __init__(self, qa: _Optional[str] = ...) -> None: ...

class MistakesSubmitResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: MistakesSubmitResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[MistakesSubmitResponseBody, _Mapping]] = ...,
    ) -> None: ...

class MistakesSubmitResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.knowledge import knowledge_pb2 as yeying_dot_api_dot_knowledge_dot_knowledge__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/knowledge/knowledge_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class KnowledgeStub(object):
    """*
    数字内容的流动采用生产、存储、服务分离的技术，也就是采归采、存归存、取归取方式。以文本内容为例，爬取内容、创作内容、分发内容、以及阅读内容，独立
    运作，只要接口版本匹配就能工作，然后以创作和阅读作为网络驱动力和激励核心因素，主要目的有两个：
    1、促进在分散式网络（web3网络中）中从新分配网络资源和流量；
    2、减少重复工作，协作保持内容新鲜度；

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Search = channel.unary_unary(
            "/yeying.api.content.Knowledge/Search",
            request_serializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.SearchRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.SearchResponse.FromString,
            _registered_method=True,
        )
        self.Append = channel.unary_unary(
            "/yeying.api.content.Knowledge/Append",
            request_serializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.AppendRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.AppendResponse.FromString,
            _registered_method=True,
        )


class KnowledgeServicer(object):
    """*
    数字内容的流动采用生产、存储、服务分离的技术，也就是采归采、存归存、取归取方式。以文本内容为例，爬取内容、创作内容、分发内容、以及阅读内容，独立
    运作，只要接口版本匹配就能工作，然后以创作和阅读作为网络驱动力和激励核心因素，主要目的有两个：
    1、促进在分散式网络（web3网络中）中从新分配网络资源和流量；
    2、减少重复工作，协作保持内容新鲜度；

    """

    def Search(self, request, context):
        """*
        内容通知
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Append(self, request, context):
        """*
        内容保鲜
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_KnowledgeServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Search": grpc.unary_unary_rpc_method_handler(
            servicer.Search,
            request_deserializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.SearchRequest.FromString,
            response_serializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.SearchResponse.SerializeToString,
        ),
        "Append": grpc.unary_unary_rpc_method_handler(
            servicer.Append,
            request_deserializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.AppendRequest.FromString,
            response_serializer=yeying_dot_api_dot_knowledge_dot_knowledge__pb2.AppendResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.content.Knowledge", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.content.Knowledge", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Knowledge(object):
    """*
    数字内容的流动采用生产、存储、服务分离的技术，也就是采归采、存归存、取归取方式。以文本内容为例，爬取内容、创作内容、分发内容、以及阅读内容，独立
    运作，只要接口版本匹配就能工作，然后以创作和阅读作为网络驱动力和激励核心因素，主要目的有两个：
    1、促进在分散式网络（web3网络中）中从新分配网络资源和流量；
    2、减少重复工作，协作保持内容新鲜度；

    """

    @staticmethod
    def Search(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.content.Knowledge/Search",
            yeying_dot_api_dot_knowledge_dot_knowledge__pb2.SearchRequest.SerializeToString,
            yeying_dot_api_dot_knowledge_dot_knowledge__pb2.SearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Append(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.content.Knowledge/Append",
            yeying_dot_api_dot_knowledge_dot_knowledge__pb2.AppendRequest.SerializeToString,
            yeying_dot_api_dot_knowledge_dot_knowledge__pb2.AppendResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by protobuf_init. Do not edit manually.
from .user_pb2 import UpdateStatusRequest
from .user_pb2 import UpdateStatusRequestBody
from .user_pb2 import UpdateStatusResponse
from .user_pb2 import UpdateStatusResponseBody
from .user_pb2 import UserListRequest
from .user_pb2 import UserListRequestBody
from .user_pb2 import UserListResponse
from .user_pb2 import UserListResponseBody
from .user_pb2 import UserMetadata
from .user_pb2 import UserState
from .user_pb2 import AddUserRequest
from .user_pb2 import AddUserRequestBody
from .user_pb2 import AddUserResponse
from .user_pb2 import AddUserResponseBody
from .user_pb2 import UpdateUserRequest
from .user_pb2 import UpdateUserRequestBody
from .user_pb2 import UpdateUserResponse
from .user_pb2 import UpdateUserResponseBody
from .user_pb2 import DeleteUserRequest
from .user_pb2 import DeleteUserResponse
from .user_pb2 import DeleteUserResponseBody
from .user_pb2 import UserDetailRequest
from .user_pb2 import UserDetailResponse
from .user_pb2 import UserDetailResponseBody
from .user_pb2 import UserDetail
from .user_pb2 import UserStatusEnum
from .user_pb2 import UserRoleEnum
from .user_pb2_grpc import UserServicer
from .user_pb2_grpc import UserStub
from .user_pb2_grpc import add_UserServicer_to_server
from .user_pb2_grpc import User



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/service/service.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/service/service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2
from yeying.api.common import model_pb2 as yeying_dot_api_dot_common_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n yeying/api/service/service.proto\x12\x12yeying.api.service\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto\x1a\x1dyeying/api/common/model.proto"\x84\x01\n\x14\x43reateServiceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.service.CreateServiceRequestBody"O\n\x18\x43reateServiceRequestBody\x12\x33\n\x07service\x18\x01 \x01(\x0b\x32".yeying.api.common.ServiceMetadata"\x86\x01\n\x15\x43reateServiceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.service.CreateServiceResponseBody"\x83\x01\n\x19\x43reateServiceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\x07service\x18\x02 \x01(\x0b\x32".yeying.api.common.ServiceMetadata"\x84\x01\n\x14\x44\x65tailServiceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.service.DetailServiceRequestBody"8\n\x18\x44\x65tailServiceRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x86\x01\n\x15\x44\x65tailServiceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.service.DetailServiceResponseBody"\x83\x01\n\x19\x44\x65tailServiceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\x07service\x18\x02 \x01(\x0b\x32".yeying.api.common.ServiceMetadata"\x84\x01\n\x14SearchServiceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.service.SearchServiceRequestBody"\x87\x01\n\x18SearchServiceRequestBody\x12=\n\tcondition\x18\x01 \x01(\x0b\x32*.yeying.api.service.SearchServiceCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"x\n\x16SearchServiceCondition\x12\x30\n\x04\x63ode\x18\x01 \x01(\x0e\x32".yeying.api.common.ServiceCodeEnum\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07keyword\x18\x04 \x01(\t"\x86\x01\n\x15SearchServiceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.service.SearchServiceResponseBody"\xb3\x01\n\x19SearchServiceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x34\n\x08services\x18\x02 \x03(\x0b\x32".yeying.api.common.ServiceMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\x84\x01\n\x14OnlineServiceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.service.OnlineServiceRequestBody"8\n\x18OnlineServiceRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x86\x01\n\x15OnlineServiceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.service.OnlineServiceResponseBody"\x83\x01\n\x19OnlineServiceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\x07service\x18\x02 \x01(\x0b\x32".yeying.api.common.ServiceMetadata"\x86\x01\n\x15OfflineServiceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.service.OfflineServiceRequestBody"9\n\x19OfflineServiceRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x88\x01\n\x16OfflineServiceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12<\n\x04\x62ody\x18\x02 \x01(\x0b\x32..yeying.api.service.OfflineServiceResponseBody"\x84\x01\n\x1aOfflineServiceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\x07service\x18\x02 \x01(\x0b\x32".yeying.api.common.ServiceMetadata"\x84\x01\n\x14\x44\x65leteServiceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.service.DeleteServiceRequestBody"8\n\x18\x44\x65leteServiceRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x86\x01\n\x15\x44\x65leteServiceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.service.DeleteServiceResponseBody"N\n\x19\x44\x65leteServiceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xd2\x04\n\x07Service\x12_\n\x06\x43reate\x12(.yeying.api.service.CreateServiceRequest\x1a).yeying.api.service.CreateServiceResponse"\x00\x12_\n\x06\x44\x65tail\x12(.yeying.api.service.DetailServiceRequest\x1a).yeying.api.service.DetailServiceResponse"\x00\x12_\n\x06Search\x12(.yeying.api.service.SearchServiceRequest\x1a).yeying.api.service.SearchServiceResponse"\x00\x12_\n\x06Online\x12(.yeying.api.service.OnlineServiceRequest\x1a).yeying.api.service.OnlineServiceResponse"\x00\x12\x62\n\x07Offline\x12).yeying.api.service.OfflineServiceRequest\x1a*.yeying.api.service.OfflineServiceResponse"\x00\x12_\n\x06\x44\x65lete\x12(.yeying.api.service.DeleteServiceRequest\x1a).yeying.api.service.DeleteServiceResponse"\x00\x42\x14Z\x12yeying/api/serviceb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.service.service_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/service"
    _globals["_CREATESERVICEREQUEST"]._serialized_start = 151
    _globals["_CREATESERVICEREQUEST"]._serialized_end = 283
    _globals["_CREATESERVICEREQUESTBODY"]._serialized_start = 285
    _globals["_CREATESERVICEREQUESTBODY"]._serialized_end = 364
    _globals["_CREATESERVICERESPONSE"]._serialized_start = 367
    _globals["_CREATESERVICERESPONSE"]._serialized_end = 501
    _globals["_CREATESERVICERESPONSEBODY"]._serialized_start = 504
    _globals["_CREATESERVICERESPONSEBODY"]._serialized_end = 635
    _globals["_DETAILSERVICEREQUEST"]._serialized_start = 638
    _globals["_DETAILSERVICEREQUEST"]._serialized_end = 770
    _globals["_DETAILSERVICEREQUESTBODY"]._serialized_start = 772
    _globals["_DETAILSERVICEREQUESTBODY"]._serialized_end = 828
    _globals["_DETAILSERVICERESPONSE"]._serialized_start = 831
    _globals["_DETAILSERVICERESPONSE"]._serialized_end = 965
    _globals["_DETAILSERVICERESPONSEBODY"]._serialized_start = 968
    _globals["_DETAILSERVICERESPONSEBODY"]._serialized_end = 1099
    _globals["_SEARCHSERVICEREQUEST"]._serialized_start = 1102
    _globals["_SEARCHSERVICEREQUEST"]._serialized_end = 1234
    _globals["_SEARCHSERVICEREQUESTBODY"]._serialized_start = 1237
    _globals["_SEARCHSERVICEREQUESTBODY"]._serialized_end = 1372
    _globals["_SEARCHSERVICECONDITION"]._serialized_start = 1374
    _globals["_SEARCHSERVICECONDITION"]._serialized_end = 1494
    _globals["_SEARCHSERVICERESPONSE"]._serialized_start = 1497
    _globals["_SEARCHSERVICERESPONSE"]._serialized_end = 1631
    _globals["_SEARCHSERVICERESPONSEBODY"]._serialized_start = 1634
    _globals["_SEARCHSERVICERESPONSEBODY"]._serialized_end = 1813
    _globals["_ONLINESERVICEREQUEST"]._serialized_start = 1816
    _globals["_ONLINESERVICEREQUEST"]._serialized_end = 1948
    _globals["_ONLINESERVICEREQUESTBODY"]._serialized_start = 1950
    _globals["_ONLINESERVICEREQUESTBODY"]._serialized_end = 2006
    _globals["_ONLINESERVICERESPONSE"]._serialized_start = 2009
    _globals["_ONLINESERVICERESPONSE"]._serialized_end = 2143
    _globals["_ONLINESERVICERESPONSEBODY"]._serialized_start = 2146
    _globals["_ONLINESERVICERESPONSEBODY"]._serialized_end = 2277
    _globals["_OFFLINESERVICEREQUEST"]._serialized_start = 2280
    _globals["_OFFLINESERVICEREQUEST"]._serialized_end = 2414
    _globals["_OFFLINESERVICEREQUESTBODY"]._serialized_start = 2416
    _globals["_OFFLINESERVICEREQUESTBODY"]._serialized_end = 2473
    _globals["_OFFLINESERVICERESPONSE"]._serialized_start = 2476
    _globals["_OFFLINESERVICERESPONSE"]._serialized_end = 2612
    _globals["_OFFLINESERVICERESPONSEBODY"]._serialized_start = 2615
    _globals["_OFFLINESERVICERESPONSEBODY"]._serialized_end = 2747
    _globals["_DELETESERVICEREQUEST"]._serialized_start = 2750
    _globals["_DELETESERVICEREQUEST"]._serialized_end = 2882
    _globals["_DELETESERVICEREQUESTBODY"]._serialized_start = 2884
    _globals["_DELETESERVICEREQUESTBODY"]._serialized_end = 2940
    _globals["_DELETESERVICERESPONSE"]._serialized_start = 2943
    _globals["_DELETESERVICERESPONSE"]._serialized_end = 3077
    _globals["_DELETESERVICERESPONSEBODY"]._serialized_start = 3079
    _globals["_DELETESERVICERESPONSEBODY"]._serialized_end = 3157
    _globals["_SERVICE"]._serialized_start = 3160
    _globals["_SERVICE"]._serialized_end = 3754
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/session/session.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/session/session.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n yeying/api/session/session.proto\x12\x12yeying.api.session\x1a\x1fyeying/api/common/message.proto"\x84\x01\n\x14\x43reateSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.CreateSessionRequestBody"P\n\x18\x43reateSessionRequestBody\x12\x34\n\x07session\x18\x01 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x86\x01\n\x15\x43reateSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.CreateSessionResponseBody"\x84\x01\n\x19\x43reateSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x34\n\x07session\x18\x02 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x84\x01\n\x14SessionDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.SessionDetailRequestBody"\'\n\x18SessionDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x86\x01\n\x15SessionDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.SessionDetailResponseBody"\x81\x01\n\x19SessionDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x31\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32!.yeying.api.session.SessionDetail"E\n\rSessionDetail\x12\x34\n\x07session\x18\x01 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x84\x01\n\x14\x44\x65leteSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.DeleteSessionRequestBody"\'\n\x18\x44\x65leteSessionRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x86\x01\n\x15\x44\x65leteSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.DeleteSessionResponseBody"N\n\x19\x44\x65leteSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x84\x01\n\x14SearchSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.SearchSessionRequestBody"\x87\x01\n\x18SearchSessionRequestBody\x12=\n\tcondition\x18\x01 \x01(\x0b\x32*.yeying.api.session.SearchSessionCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"3\n\x16SearchSessionCondition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t"\x86\x01\n\x15SearchSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.SearchSessionResponseBody"\x85\x01\n\x19SearchSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x35\n\x08sessions\x18\x02 \x03(\x0b\x32#.yeying.api.session.SessionMetadata"\x84\x01\n\x14UpdateSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.UpdateSessionRequestBody"P\n\x18UpdateSessionRequestBody\x12\x34\n\x07session\x18\x01 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x86\x01\n\x15UpdateSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.UpdateSessionResponseBody"\x84\x01\n\x19UpdateSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x34\n\x07session\x18\x02 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x99\x01\n\x0fSessionMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x11\n\tupdatedAt\x18\x07 \x01(\t\x12\x11\n\tsignature\x18\x08 \x01(\t2\xee\x03\n\x07Session\x12_\n\x06\x43reate\x12(.yeying.api.session.CreateSessionRequest\x1a).yeying.api.session.CreateSessionResponse"\x00\x12_\n\x06\x44\x65lete\x12(.yeying.api.session.DeleteSessionRequest\x1a).yeying.api.session.DeleteSessionResponse"\x00\x12_\n\x06\x44\x65tail\x12(.yeying.api.session.SessionDetailRequest\x1a).yeying.api.session.SessionDetailResponse"\x00\x12_\n\x06Search\x12(.yeying.api.session.SearchSessionRequest\x1a).yeying.api.session.SearchSessionResponse"\x00\x12_\n\x06Update\x12(.yeying.api.session.UpdateSessionRequest\x1a).yeying.api.session.UpdateSessionResponse"\x00\x42\x14Z\x12yeying/api/sessionb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.session.session_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/session"
    _globals["_CREATESESSIONREQUEST"]._serialized_start = 90
    _globals["_CREATESESSIONREQUEST"]._serialized_end = 222
    _globals["_CREATESESSIONREQUESTBODY"]._serialized_start = 224
    _globals["_CREATESESSIONREQUESTBODY"]._serialized_end = 304
    _globals["_CREATESESSIONRESPONSE"]._serialized_start = 307
    _globals["_CREATESESSIONRESPONSE"]._serialized_end = 441
    _globals["_CREATESESSIONRESPONSEBODY"]._serialized_start = 444
    _globals["_CREATESESSIONRESPONSEBODY"]._serialized_end = 576
    _globals["_SESSIONDETAILREQUEST"]._serialized_start = 579
    _globals["_SESSIONDETAILREQUEST"]._serialized_end = 711
    _globals["_SESSIONDETAILREQUESTBODY"]._serialized_start = 713
    _globals["_SESSIONDETAILREQUESTBODY"]._serialized_end = 752
    _globals["_SESSIONDETAILRESPONSE"]._serialized_start = 755
    _globals["_SESSIONDETAILRESPONSE"]._serialized_end = 889
    _globals["_SESSIONDETAILRESPONSEBODY"]._serialized_start = 892
    _globals["_SESSIONDETAILRESPONSEBODY"]._serialized_end = 1021
    _globals["_SESSIONDETAIL"]._serialized_start = 1023
    _globals["_SESSIONDETAIL"]._serialized_end = 1092
    _globals["_DELETESESSIONREQUEST"]._serialized_start = 1095
    _globals["_DELETESESSIONREQUEST"]._serialized_end = 1227
    _globals["_DELETESESSIONREQUESTBODY"]._serialized_start = 1229
    _globals["_DELETESESSIONREQUESTBODY"]._serialized_end = 1268
    _globals["_DELETESESSIONRESPONSE"]._serialized_start = 1271
    _globals["_DELETESESSIONRESPONSE"]._serialized_end = 1405
    _globals["_DELETESESSIONRESPONSEBODY"]._serialized_start = 1407
    _globals["_DELETESESSIONRESPONSEBODY"]._serialized_end = 1485
    _globals["_SEARCHSESSIONREQUEST"]._serialized_start = 1488
    _globals["_SEARCHSESSIONREQUEST"]._serialized_end = 1620
    _globals["_SEARCHSESSIONREQUESTBODY"]._serialized_start = 1623
    _globals["_SEARCHSESSIONREQUESTBODY"]._serialized_end = 1758
    _globals["_SEARCHSESSIONCONDITION"]._serialized_start = 1760
    _globals["_SEARCHSESSIONCONDITION"]._serialized_end = 1811
    _globals["_SEARCHSESSIONRESPONSE"]._serialized_start = 1814
    _globals["_SEARCHSESSIONRESPONSE"]._serialized_end = 1948
    _globals["_SEARCHSESSIONRESPONSEBODY"]._serialized_start = 1951
    _globals["_SEARCHSESSIONRESPONSEBODY"]._serialized_end = 2084
    _globals["_UPDATESESSIONREQUEST"]._serialized_start = 2087
    _globals["_UPDATESESSIONREQUEST"]._serialized_end = 2219
    _globals["_UPDATESESSIONREQUESTBODY"]._serialized_start = 2221
    _globals["_UPDATESESSIONREQUESTBODY"]._serialized_end = 2301
    _globals["_UPDATESESSIONRESPONSE"]._serialized_start = 2304
    _globals["_UPDATESESSIONRESPONSE"]._serialized_end = 2438
    _globals["_UPDATESESSIONRESPONSEBODY"]._serialized_start = 2441
    _globals["_UPDATESESSIONRESPONSEBODY"]._serialized_end = 2573
    _globals["_SESSIONMETADATA"]._serialized_start = 2576
    _globals["_SESSIONMETADATA"]._serialized_end = 2729
    _globals["_SESSION"]._serialized_start = 2732
    _globals["_SESSION"]._serialized_end = 3226
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/bulletin/bulletin.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/bulletin/bulletin.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"yeying/api/bulletin/bulletin.proto\x12\x13yeying.api.bulletin\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"\x83\x01\n\x13\x42ulletinListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.bulletin.BulletinListRequestBody"\xb3\x01\n\x17\x42ulletinListRequestBody\x12\x33\n\x04\x63ode\x18\x01 \x01(\x0e\x32%.yeying.api.bulletin.BulletinCodeEnum\x12\x35\n\x08language\x18\x02 \x01(\x0e\x32#.yeying.api.common.LanguageCodeEnum\x12,\n\x04page\x18\x03 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x85\x01\n\x14\x42ulletinListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.bulletin.BulletinListResponseBody"\xb6\x01\n\x18\x42ulletinListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x38\n\tsolutions\x18\x02 \x03(\x0b\x32%.yeying.api.bulletin.SolutionMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\xe4\x01\n\x10SolutionMetadata\x12\x11\n\tpublisher\x18\x01 \x01(\t\x12\x35\n\x08language\x18\x02 \x01(\x0e\x32#.yeying.api.common.LanguageCodeEnum\x12\x0b\n\x03uid\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x30\n\x05\x63\x61rds\x18\x07 \x03(\x0b\x32!.yeying.api.bulletin.SolutionCard\x12\x11\n\tsignature\x18\x08 \x01(\t">\n\x0cSolutionCard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\t\x12\x11\n\tvariables\x18\x03 \x01(\t*.\n\x10\x42ulletinCodeEnum\x12\x1a\n\x16\x42ULLETIN_CODE_SOLUTION\x10\x00\x32i\n\x08\x42ulletin\x12]\n\x04List\x12(.yeying.api.bulletin.BulletinListRequest\x1a).yeying.api.bulletin.BulletinListResponse"\x00\x42\x15Z\x13yeying/api/bulletinb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.bulletin.bulletin_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\023yeying/api/bulletin"
    _globals["_BULLETINCODEENUM"]._serialized_start = 1054
    _globals["_BULLETINCODEENUM"]._serialized_end = 1100
    _globals["_BULLETINLISTREQUEST"]._serialized_start = 123
    _globals["_BULLETINLISTREQUEST"]._serialized_end = 254
    _globals["_BULLETINLISTREQUESTBODY"]._serialized_start = 257
    _globals["_BULLETINLISTREQUESTBODY"]._serialized_end = 436
    _globals["_BULLETINLISTRESPONSE"]._serialized_start = 439
    _globals["_BULLETINLISTRESPONSE"]._serialized_end = 572
    _globals["_BULLETINLISTRESPONSEBODY"]._serialized_start = 575
    _globals["_BULLETINLISTRESPONSEBODY"]._serialized_end = 757
    _globals["_SOLUTIONMETADATA"]._serialized_start = 760
    _globals["_SOLUTIONMETADATA"]._serialized_end = 988
    _globals["_SOLUTIONCARD"]._serialized_start = 990
    _globals["_SOLUTIONCARD"]._serialized_end = 1052
    _globals["_BULLETIN"]._serialized_start = 1102
    _globals["_BULLETIN"]._serialized_end = 1207
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/link.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/link.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1byeying/api/asset/link.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto"|\n\x11\x43reateLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.CreateLinkRequestBody"E\n\x15\x43reateLinkRequestBody\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12\x43reateLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.CreateLinkResponseBody"y\n\x16\x43reateLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12,\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1c.yeying.api.asset.LinkDetail"|\n\x11SearchLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.SearchLinkRequestBody"\x7f\n\x15SearchLinkRequestBody\x12,\n\x04page\x18\x01 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage\x12\x38\n\tcondition\x18\x02 \x01(\x0b\x32%.yeying.api.asset.SearchLinkCondition"#\n\x13SearchLinkCondition\x12\x0c\n\x04hash\x18\x01 \x01(\t"~\n\x12SearchLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.SearchLinkResponseBody"\xa9\x01\n\x16SearchLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04page\x18\x02 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage\x12-\n\x05links\x18\x03 \x03(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12\x44isableLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.DisableLinkRequestBody"(\n\x16\x44isableLinkRequestBody\x12\x0e\n\x06linkId\x18\x01 \x01(\t"\x80\x01\n\x13\x44isableLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.DisableLinkResponseBody"L\n\x17\x44isableLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"|\n\x11UpdateLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.UpdateLinkRequestBody"E\n\x15UpdateLinkRequestBody\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12UpdateLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.UpdateLinkResponseBody"y\n\x16UpdateLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12,\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1c.yeying.api.asset.LinkDetail"|\n\x11LinkDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.LinkDetailRequestBody"$\n\x15LinkDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"~\n\x12LinkDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.LinkDetailResponseBody"y\n\x16LinkDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12,\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1c.yeying.api.asset.LinkDetail"f\n\nLinkDetail\x12*\n\x03url\x18\x01 \x01(\x0b\x32\x1d.yeying.api.asset.UrlMetadata\x12,\n\x04link\x18\x02 \x01(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12LinkVisitorRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.LinkVisitorRequestBody"S\n\x16LinkVisitorRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x80\x01\n\x13LinkVisitorResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.LinkVisitorResponseBody"\xb0\x01\n\x17LinkVisitorResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04page\x18\x02 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage\x12\x33\n\x08visitors\x18\x03 \x03(\x0b\x32!.yeying.api.asset.VisitorMetadata"\x8b\x02\n\x0cLinkMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12,\n\x04type\x18\x03 \x01(\x0e\x32\x1e.yeying.api.asset.LinkTypeEnum\x12\x10\n\x08visitors\x18\x04 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x0c\n\x04hash\x18\x08 \x01(\t\x12\r\n\x05token\x18\t \x01(\t\x12\x11\n\tstartedAt\x18\n \x01(\t\x12\x11\n\texpiredAt\x18\x0b \x01(\t\x12\x11\n\tcreatedAt\x18\x0c \x01(\t\x12\x11\n\tsignature\x18\r \x01(\t"\xb7\x01\n\x0bUrlMetadata\x12\x12\n\nserviceDid\x18\x01 \x01(\t\x12\x0e\n\x06linkId\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12/\n\x06status\x18\x05 \x01(\x0e\x32\x1f.yeying.api.asset.UrlStatusEnum\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x11\n\tupdatedAt\x18\x07 \x01(\t\x12\x11\n\tsignature\x18\x08 \x01(\t"T\n\x0fVisitorMetadata\x12\x0e\n\x06linkId\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t*V\n\rUrlStatusEnum\x12\x16\n\x12URL_STATUS_UNKNOWN\x10\x00\x12\x15\n\x11URL_STATUS_ENABLE\x10\x01\x12\x16\n\x12URL_STATUS_DISABLE\x10\x02*X\n\x0cLinkTypeEnum\x12\x15\n\x11LINK_TYPE_UNKNOWN\x10\x00\x12\x14\n\x10LINK_TYPE_PUBLIC\x10\x01\x12\x1b\n\x17LINK_TYPE_AUTHENTICATED\x10\x02\x32\x96\x04\n\x04Link\x12U\n\x06\x43reate\x12#.yeying.api.asset.CreateLinkRequest\x1a$.yeying.api.asset.CreateLinkResponse"\x00\x12U\n\x06Search\x12#.yeying.api.asset.SearchLinkRequest\x1a$.yeying.api.asset.SearchLinkResponse"\x00\x12U\n\x06\x44\x65tail\x12#.yeying.api.asset.LinkDetailRequest\x1a$.yeying.api.asset.LinkDetailResponse"\x00\x12X\n\x07Visitor\x12$.yeying.api.asset.LinkVisitorRequest\x1a%.yeying.api.asset.LinkVisitorResponse"\x00\x12X\n\x07\x44isable\x12$.yeying.api.asset.DisableLinkRequest\x1a%.yeying.api.asset.DisableLinkResponse"\x00\x12U\n\x06Update\x12#.yeying.api.asset.UpdateLinkRequest\x1a$.yeying.api.asset.UpdateLinkResponse"\x00\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.link_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_URLSTATUSENUM"]._serialized_start = 3533
    _globals["_URLSTATUSENUM"]._serialized_end = 3619
    _globals["_LINKTYPEENUM"]._serialized_start = 3621
    _globals["_LINKTYPEENUM"]._serialized_end = 3709
    _globals["_CREATELINKREQUEST"]._serialized_start = 82
    _globals["_CREATELINKREQUEST"]._serialized_end = 206
    _globals["_CREATELINKREQUESTBODY"]._serialized_start = 208
    _globals["_CREATELINKREQUESTBODY"]._serialized_end = 277
    _globals["_CREATELINKRESPONSE"]._serialized_start = 279
    _globals["_CREATELINKRESPONSE"]._serialized_end = 405
    _globals["_CREATELINKRESPONSEBODY"]._serialized_start = 407
    _globals["_CREATELINKRESPONSEBODY"]._serialized_end = 528
    _globals["_SEARCHLINKREQUEST"]._serialized_start = 530
    _globals["_SEARCHLINKREQUEST"]._serialized_end = 654
    _globals["_SEARCHLINKREQUESTBODY"]._serialized_start = 656
    _globals["_SEARCHLINKREQUESTBODY"]._serialized_end = 783
    _globals["_SEARCHLINKCONDITION"]._serialized_start = 785
    _globals["_SEARCHLINKCONDITION"]._serialized_end = 820
    _globals["_SEARCHLINKRESPONSE"]._serialized_start = 822
    _globals["_SEARCHLINKRESPONSE"]._serialized_end = 948
    _globals["_SEARCHLINKRESPONSEBODY"]._serialized_start = 951
    _globals["_SEARCHLINKRESPONSEBODY"]._serialized_end = 1120
    _globals["_DISABLELINKREQUEST"]._serialized_start = 1122
    _globals["_DISABLELINKREQUEST"]._serialized_end = 1248
    _globals["_DISABLELINKREQUESTBODY"]._serialized_start = 1250
    _globals["_DISABLELINKREQUESTBODY"]._serialized_end = 1290
    _globals["_DISABLELINKRESPONSE"]._serialized_start = 1293
    _globals["_DISABLELINKRESPONSE"]._serialized_end = 1421
    _globals["_DISABLELINKRESPONSEBODY"]._serialized_start = 1423
    _globals["_DISABLELINKRESPONSEBODY"]._serialized_end = 1499
    _globals["_UPDATELINKREQUEST"]._serialized_start = 1501
    _globals["_UPDATELINKREQUEST"]._serialized_end = 1625
    _globals["_UPDATELINKREQUESTBODY"]._serialized_start = 1627
    _globals["_UPDATELINKREQUESTBODY"]._serialized_end = 1696
    _globals["_UPDATELINKRESPONSE"]._serialized_start = 1698
    _globals["_UPDATELINKRESPONSE"]._serialized_end = 1824
    _globals["_UPDATELINKRESPONSEBODY"]._serialized_start = 1826
    _globals["_UPDATELINKRESPONSEBODY"]._serialized_end = 1947
    _globals["_LINKDETAILREQUEST"]._serialized_start = 1949
    _globals["_LINKDETAILREQUEST"]._serialized_end = 2073
    _globals["_LINKDETAILREQUESTBODY"]._serialized_start = 2075
    _globals["_LINKDETAILREQUESTBODY"]._serialized_end = 2111
    _globals["_LINKDETAILRESPONSE"]._serialized_start = 2113
    _globals["_LINKDETAILRESPONSE"]._serialized_end = 2239
    _globals["_LINKDETAILRESPONSEBODY"]._serialized_start = 2241
    _globals["_LINKDETAILRESPONSEBODY"]._serialized_end = 2362
    _globals["_LINKDETAIL"]._serialized_start = 2364
    _globals["_LINKDETAIL"]._serialized_end = 2466
    _globals["_LINKVISITORREQUEST"]._serialized_start = 2468
    _globals["_LINKVISITORREQUEST"]._serialized_end = 2594
    _globals["_LINKVISITORREQUESTBODY"]._serialized_start = 2596
    _globals["_LINKVISITORREQUESTBODY"]._serialized_end = 2679
    _globals["_LINKVISITORRESPONSE"]._serialized_start = 2682
    _globals["_LINKVISITORRESPONSE"]._serialized_end = 2810
    _globals["_LINKVISITORRESPONSEBODY"]._serialized_start = 2813
    _globals["_LINKVISITORRESPONSEBODY"]._serialized_end = 2989
    _globals["_LINKMETADATA"]._serialized_start = 2992
    _globals["_LINKMETADATA"]._serialized_end = 3259
    _globals["_URLMETADATA"]._serialized_start = 3262
    _globals["_URLMETADATA"]._serialized_end = 3445
    _globals["_VISITORMETADATA"]._serialized_start = 3447
    _globals["_VISITORMETADATA"]._serialized_end = 3531
    _globals["_LINK"]._serialized_start = 3712
    _globals["_LINK"]._serialized_end = 4246
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .service_pb2 import CreateServiceRequest
from .service_pb2 import CreateServiceRequestBody
from .service_pb2 import CreateServiceResponse
from .service_pb2 import CreateServiceResponseBody
from .service_pb2 import DetailServiceRequest
from .service_pb2 import DetailServiceRequestBody
from .service_pb2 import DetailServiceResponse
from .service_pb2 import DetailServiceResponseBody
from .service_pb2 import SearchServiceRequest
from .service_pb2 import SearchServiceRequestBody
from .service_pb2 import SearchServiceCondition
from .service_pb2 import SearchServiceResponse
from .service_pb2 import SearchServiceResponseBody
from .service_pb2 import OnlineServiceRequest
from .service_pb2 import OnlineServiceRequestBody
from .service_pb2 import OnlineServiceResponse
from .service_pb2 import OnlineServiceResponseBody
from .service_pb2 import OfflineServiceRequest
from .service_pb2 import OfflineServiceRequestBody
from .service_pb2 import OfflineServiceResponse
from .service_pb2 import OfflineServiceResponseBody
from .service_pb2 import DeleteServiceRequest
from .service_pb2 import DeleteServiceRequestBody
from .service_pb2 import DeleteServiceResponse
from .service_pb2 import DeleteServiceResponseBody
from .service_pb2_grpc import ServiceServicer
from .service_pb2_grpc import ServiceStub
from .service_pb2_grpc import add_ServiceServicer_to_server
from .service_pb2_grpc import Service



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfirmBlockRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ConfirmBlockRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ConfirmBlockRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ConfirmBlockRequestBody(_message.Message):
    __slots__ = ("block",)
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block: BlockMetadata
    def __init__(self, block: _Optional[_Union[BlockMetadata, _Mapping]] = ...) -> None: ...

class ConfirmBlockResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ConfirmBlockResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ConfirmBlockResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ConfirmBlockResponseBody(_message.Message):
    __slots__ = ("status", "block")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    block: BlockMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        block: _Optional[_Union[BlockMetadata, _Mapping]] = ...,
    ) -> None: ...

class StreamPutBlockRequest(_message.Message):
    __slots__ = ("head", "body", "Tail")
    HEAD_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TAIL_FIELD_NUMBER: _ClassVar[int]
    head: StreamPutBlockRequestHead
    body: StreamPutBlockRequestBody
    Tail: StreamPutBlockRequestTail
    def __init__(
        self,
        head: _Optional[_Union[StreamPutBlockRequestHead, _Mapping]] = ...,
        body: _Optional[_Union[StreamPutBlockRequestBody, _Mapping]] = ...,
        Tail: _Optional[_Union[StreamPutBlockRequestTail, _Mapping]] = ...,
    ) -> None: ...

class StreamPutBlockRequestHead(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StreamPutBlockRequestHeadBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StreamPutBlockRequestHeadBody, _Mapping]] = ...,
    ) -> None: ...

class StreamPutBlockRequestHeadBody(_message.Message):
    __slots__ = ("block",)
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block: BlockMetadata
    def __init__(self, block: _Optional[_Union[BlockMetadata, _Mapping]] = ...) -> None: ...

class StreamPutBlockRequestBody(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class StreamPutBlockRequestTail(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class StreamPutBlockResponse(_message.Message):
    __slots__ = ("head", "tail")
    HEAD_FIELD_NUMBER: _ClassVar[int]
    TAIL_FIELD_NUMBER: _ClassVar[int]
    head: StreamPutBlockResponseHead
    tail: StreamPutBlockResponseTail
    def __init__(
        self,
        head: _Optional[_Union[StreamPutBlockResponseHead, _Mapping]] = ...,
        tail: _Optional[_Union[StreamPutBlockResponseTail, _Mapping]] = ...,
    ) -> None: ...

class StreamPutBlockResponseHead(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StreamPutBlockResponseHeadBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StreamPutBlockResponseHeadBody, _Mapping]] = ...,
    ) -> None: ...

class StreamPutBlockResponseHeadBody(_message.Message):
    __slots__ = ("status", "block")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    block: BlockMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        block: _Optional[_Union[BlockMetadata, _Mapping]] = ...,
    ) -> None: ...

class StreamPutBlockResponseTail(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StreamPutBlockResponseTailBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StreamPutBlockResponseTailBody, _Mapping]] = ...,
    ) -> None: ...

class StreamPutBlockResponseTailBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class PutBlockRequest(_message.Message):
    __slots__ = ("header", "body", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: PutBlockRequestBody
    data: bytes
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[PutBlockRequestBody, _Mapping]] = ...,
        data: _Optional[bytes] = ...,
    ) -> None: ...

class PutBlockRequestBody(_message.Message):
    __slots__ = ("block",)
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block: BlockMetadata
    def __init__(self, block: _Optional[_Union[BlockMetadata, _Mapping]] = ...) -> None: ...

class PutBlockResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: PutBlockResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[PutBlockResponseBody, _Mapping]] = ...,
    ) -> None: ...

class PutBlockResponseBody(_message.Message):
    __slots__ = ("status", "block")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    block: BlockMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        block: _Optional[_Union[BlockMetadata, _Mapping]] = ...,
    ) -> None: ...

class GetBlockRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: GetBlockRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[GetBlockRequestBody, _Mapping]] = ...,
    ) -> None: ...

class GetBlockRequestBody(_message.Message):
    __slots__ = ("namespaceId", "hash")
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    namespaceId: str
    hash: str
    def __init__(self, namespaceId: _Optional[str] = ..., hash: _Optional[str] = ...) -> None: ...

class StreamGetBlockRequest(_message.Message):
    __slots__ = ("head", "body")
    HEAD_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    head: StreamGetBlockRequestHead
    body: StreamGetBlockRequestBody
    def __init__(
        self,
        head: _Optional[_Union[StreamGetBlockRequestHead, _Mapping]] = ...,
        body: _Optional[_Union[StreamGetBlockRequestBody, _Mapping]] = ...,
    ) -> None: ...

class StreamGetBlockRequestHead(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StreamGetBlockRequestHeadBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StreamGetBlockRequestHeadBody, _Mapping]] = ...,
    ) -> None: ...

class StreamGetBlockRequestHeadBody(_message.Message):
    __slots__ = ("namespaceId", "hash")
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    namespaceId: str
    hash: str
    def __init__(self, namespaceId: _Optional[str] = ..., hash: _Optional[str] = ...) -> None: ...

class StreamGetBlockRequestBody(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    def __init__(self, header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...) -> None: ...

class StreamGetBlockResponse(_message.Message):
    __slots__ = ("head", "body", "tail")
    HEAD_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TAIL_FIELD_NUMBER: _ClassVar[int]
    head: StreamGetBlockResponseHead
    body: StreamGetBlockResponseBody
    tail: StreamGetBlockResponseTail
    def __init__(
        self,
        head: _Optional[_Union[StreamGetBlockResponseHead, _Mapping]] = ...,
        body: _Optional[_Union[StreamGetBlockResponseBody, _Mapping]] = ...,
        tail: _Optional[_Union[StreamGetBlockResponseTail, _Mapping]] = ...,
    ) -> None: ...

class StreamGetBlockResponseHead(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StreamGetBlockResponseHeadBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StreamGetBlockResponseHeadBody, _Mapping]] = ...,
    ) -> None: ...

class StreamGetBlockResponseHeadBody(_message.Message):
    __slots__ = ("status", "block")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    block: BlockMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        block: _Optional[_Union[BlockMetadata, _Mapping]] = ...,
    ) -> None: ...

class StreamGetBlockResponseBody(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class StreamGetBlockResponseTail(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StreamGetBlockResponseTailBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StreamGetBlockResponseTailBody, _Mapping]] = ...,
    ) -> None: ...

class StreamGetBlockResponseTailBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class GetBlockResponseBody(_message.Message):
    __slots__ = ("status", "block")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    block: BlockMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        block: _Optional[_Union[BlockMetadata, _Mapping]] = ...,
    ) -> None: ...

class GetBlockResponse(_message.Message):
    __slots__ = ("header", "body", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: GetBlockResponseBody
    data: bytes
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[GetBlockResponseBody, _Mapping]] = ...,
        data: _Optional[bytes] = ...,
    ) -> None: ...

class BlockMetadata(_message.Message):
    __slots__ = ("namespaceId", "asset", "owner", "hash", "size", "createdAt", "signature")
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    UPLOADER_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    namespaceId: str
    uploader: str
    owner: str
    hash: str
    size: int
    createdAt: str
    signature: str
    def __init__(
        self,
        namespaceId: _Optional[str] = ...,
        uploader: _Optional[str] = ...,
        owner: _Optional[str] = ...,
        hash: _Optional[str] = ...,
        size: _Optional[int] = ...,
        createdAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/common/model.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/common/model.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dyeying/api/common/model.proto\x12\x11yeying.api.common\x1a\x1cyeying/api/common/code.proto"\xf9\x02\n\x13\x41pplicationMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x0b\n\x03\x64id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x0c\n\x04hash\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x34\n\x04\x63ode\x18\x08 \x01(\x0e\x32&.yeying.api.common.ApplicationCodeEnum\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x10\n\x08location\x18\n \x01(\t\x12\x38\n\x0cserviceCodes\x18\x0b \x03(\x0e\x32".yeying.api.common.ServiceCodeEnum\x12\x0e\n\x06\x61vatar\x18\x0c \x01(\t\x12\x11\n\tcreatedAt\x18\r \x01(\t\x12\x11\n\tupdatedAt\x18\x0e \x01(\t\x12\x11\n\tsignature\x18\x0f \x01(\t\x12\x17\n\x0f\x63odePackagePath\x18\x10 \x01(\t"\xe6\x02\n\x0fServiceMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x0b\n\x03\x64id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x30\n\x04\x63ode\x18\x08 \x01(\x0e\x32".yeying.api.common.ServiceCodeEnum\x12\x30\n\x08\x61piCodes\x18\t \x03(\x0e\x32\x1e.yeying.api.common.ApiCodeEnum\x12\r\n\x05proxy\x18\n \x01(\t\x12\x0c\n\x04grpc\x18\x0b \x01(\t\x12\x0e\n\x06\x61vatar\x18\x0c \x01(\t\x12\x11\n\tcreatedAt\x18\r \x01(\t\x12\x11\n\tupdatedAt\x18\x0e \x01(\t\x12\x11\n\tsignature\x18\x0f \x01(\t\x12\x17\n\x0f\x63odePackagePath\x18\x10 \x01(\t"\xd0\x01\n\rStateMetadata\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x38\n\x06status\x18\x03 \x01(\x0e\x32(.yeying.api.common.ApplicationStatusEnum\x12\x11\n\tsignature\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tupdatedAt\x18\x06 \x01(\t\x12.\n\x04type\x18\x07 \x01(\x0e\x32 .yeying.api.common.AuditTypeEnumB\x13Z\x11yeying/api/commonb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.common.model_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/common"
    _globals["_APPLICATIONMETADATA"]._serialized_start = 83
    _globals["_APPLICATIONMETADATA"]._serialized_end = 460
    _globals["_SERVICEMETADATA"]._serialized_start = 463
    _globals["_SERVICEMETADATA"]._serialized_end = 821
    _globals["_STATEMETADATA"]._serialized_start = 824
    _globals["_STATEMETADATA"]._serialized_end = 1032
# @@protoc_insertion_point(module_scope)
